@@ -366,6 +366,9 @@ func (r *AuthRealmReconciler) createDexConnectors(authRealm *identitatemv1alpha1
 					RedirectURI: dexServer.Spec.Issuer + "/callback",
 				},
 			}
+			if githubExtraConfig, ok := authRealm.Spec.GitHubExtraConfigs[idp.Name]; ok {
+				c.GitHub.LoadAllGroups = githubExtraConfig.LoadAllGroups
+			}
 			c.GitHub.Orgs = make([]dexoperatorv1alpha1.Org, len(idp.GitHub.Organizations))
 			for i, org := range idp.GitHub.Organizations {
 				c.GitHub.Orgs[i].Name = org
@@ -425,12 +428,38 @@ func (r *AuthRealmReconciler) createDexConnectors(authRealm *identitatemv1alpha1
 						EmailAttr: idp.LDAP.Attributes.Email[0],
 						NameAttr:  idp.LDAP.Attributes.Name[0],
 					},
+					GroupSearch: authRealm.Spec.LDAPExtraConfigs[idp.Name].GroupSearch,
 				},
 			}
 			r.Log.Info("generated connector", "c.LDAP", c.LDAP)
 			cs = append(cs, *c)
 			fmt.Println("cs: ", cs)
-			r.Log.Info("generated intermediate connextors", "cs", cs)
+			r.Log.Info("generated intermediate connectors", "cs", cs)
+		case openshiftconfigv1.IdentityProviderTypeOpenID:
+			r.Log.Info("create connector for OpenID")
+			c := &dexoperatorv1alpha1.ConnectorSpec{
+				Type: dexoperatorv1alpha1.ConnectorTypeOIDC,
+				Name: idp.Name,
+				Id:   idp.Name,
+				OIDC: dexoperatorv1alpha1.OIDCConfigSpec{
+					Issuer:   idp.OpenID.Issuer,
+					ClientID: idp.OpenID.ClientID,
+					ClientSecretRef: corev1.SecretReference{
+						Name:      idp.OpenID.ClientSecret.Name,
+						Namespace: authRealm.Namespace,
+					},
+					RedirectURI: dexServer.Spec.Issuer + "/callback",
+					ClaimMapping: dexoperatorv1alpha1.ClaimMappingSpec{
+						PreferredUsername: idp.OpenID.Claims.PreferredUsername,
+						Name:              idp.OpenID.Claims.Name,
+						Email:             idp.OpenID.Claims.Email,
+					},
+				},
+			}
+			r.Log.Info("generated connector", "c.OIDC", c.OIDC)
+			cs = append(cs, *c)
+			fmt.Println("cs: ", cs)
+			r.Log.Info("generated intermediate connectors", "cs", cs)
 		default:
 			return nil, giterrors.WithStack(fmt.Errorf("unsupported provider type %s", idp.Type))
 		}
