@@ -13,7 +13,7 @@ import (
 
 	ctrl "sigs.k8s.io/controller-runtime"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -28,10 +28,10 @@ import (
 	"k8s.io/client-go/rest"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/envtest"
-	"sigs.k8s.io/controller-runtime/pkg/envtest/printer"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/log/zap"
 
+	dexoperatorv1alpha1 "github.com/identitatem/dex-operator/api/v1alpha1"
 	identitatemdexserverv1lapha1 "github.com/identitatem/dex-operator/api/v1alpha1"
 	dexoperatorconfig "github.com/identitatem/dex-operator/config"
 	idpclientset "github.com/identitatem/idp-client-api/api/client/clientset/versioned"
@@ -57,12 +57,17 @@ var r AuthRealmReconciler
 func TestAPIs(t *testing.T) {
 	RegisterFailHandler(Fail)
 
-	RunSpecsWithDefaultAndCustomReporters(t,
+	// fetch the current config
+	suiteConfig, reporterConfig := GinkgoConfiguration()
+	// adjust it
+	suiteConfig.SkipStrings = []string{"NEVER-RUN"}
+	reporterConfig.FullTrace = true
+	RunSpecs(t,
 		"Controller Suite",
-		[]Reporter{printer.NewlineReporter{}})
+		reporterConfig)
 }
 
-var _ = BeforeSuite(func(done Done) {
+var _ = BeforeSuite(func() {
 	logf.SetLogger(zap.New(zap.WriteTo(GinkgoWriter), zap.UseDevMode(true)))
 
 	By("bootstrapping test environment")
@@ -97,7 +102,7 @@ var _ = BeforeSuite(func(done Done) {
 
 	testEnv = &envtest.Environment{
 		Scheme: scheme.Scheme,
-		CRDs: []client.Object{
+		CRDs: []*apiextensionsv1.CustomResourceDefinition{
 			strategyCRD,
 			authRealmCRD,
 			dexClientCRD,
@@ -152,8 +157,7 @@ var _ = BeforeSuite(func(done Done) {
 		Expect(err).NotTo(HaveOccurred())
 	})
 
-	close(done)
-}, 60)
+})
 
 var _ = AfterSuite(func() {
 	By("tearing down the test environment")
@@ -196,7 +200,7 @@ var _ = Describe("Process deployment: ", func() {
 		Expect(role.Namespace).To(Equal(values.NewNamespaceLeader))
 	})
 })
-var _ = Describe("Process AuthRealm: ", func() {
+var _ = Describe("Process AuthRealm Github: ", func() {
 	AuthRealmName := "my-authrealm"
 	AuthRealmNameSpace := "my-authrealm-ns"
 	RouteSubDomain := "myroute"
@@ -262,6 +266,11 @@ var _ = Describe("Process AuthRealm: ", func() {
 							},
 						},
 					},
+					GitHubExtraConfigs: map[string]identitatemv1alpha1.GitHubExtraConfig{
+						"my-github": {
+							LoadAllGroups: true,
+						},
+					},
 				},
 			}
 			var err error
@@ -309,6 +318,7 @@ var _ = Describe("Process AuthRealm: ", func() {
 			Expect(dexServer.Spec.Connectors[0].GitHub.ClientSecretRef.Name).To(Equal(AuthRealmName + "-" + string(openshiftconfigv1.IdentityProviderTypeGitHub)))
 			// Expect(dexServer.Spec.Connectors[0].Config.ClientSecretRef.Namespace).To(Equal(dexServerName))
 			Expect(dexServer.Spec.Connectors[0].Type).To(Equal(identitatemdexserverv1lapha1.ConnectorTypeGitHub))
+			Expect(dexServer.Spec.Connectors[0].GitHub.LoadAllGroups).To(Equal(true))
 			Expect(dexServer.Spec.IngressCertificateRef.Name).To(Equal(authRealm.Spec.CertificatesSecretRef.Name))
 			Expect(len(dexServer.Status.RelatedObjects)).To(Equal(1))
 			Expect(dexServer.Status.RelatedObjects[0].Kind).To(Equal("AuthRealm"))
@@ -484,6 +494,276 @@ var _ = Describe("Process AuthRealm: ", func() {
 
 })
 
+var _ = Describe("Process AuthRealm LDAP: ", func() {
+	AuthRealmName := "my-authrealm-ldap"
+	AuthRealmNameSpace := "my-authrealm-ldap-ns"
+	RouteSubDomain := "myroute-ldap"
+	CertificatesSecretRef := "my-certs"
+	BindDN := "cn=Manager,dc=example,dc=com"
+	Filter := "(objectClass=person)"
+	BaseDN := "dc=example,dc=com"
+	GroupFilter := "(objectClass=groupOfNames)"
+	GroupAttr := "member"
+	UserAttr := "DN"
+	NameAttr := "cn"
+	It("Check CRDs availability", func() {
+		By("Checking authrealms CRD", func() {
+			readerStrategy := idpconfig.GetScenarioResourcesReader()
+			_, err := getCRD(readerStrategy, "crd/bases/identityconfig.identitatem.io_authrealms.yaml")
+			Expect(err).Should(BeNil())
+		})
+	})
+	It("process a AuthRealm CR LDAP", func() {
+		By("creation test namespace", func() {
+			ns := &corev1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: AuthRealmNameSpace,
+				},
+			}
+			err := k8sClient.Create(context.TODO(), ns)
+			Expect(err).To(BeNil())
+		})
+		By("creating the certificate secret", func() {
+			secret := &corev1.Secret{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      CertificatesSecretRef,
+					Namespace: AuthRealmNameSpace,
+				},
+				Data: map[string][]byte{
+					"tls.crt": []byte("tls.mycrt"),
+					"tls.key": []byte("tls.mykey"),
+					"ca.crt":  []byte("ca.crt"),
+				},
+			}
+			err := k8sClient.Create(context.TODO(), secret)
+			Expect(err).To(BeNil())
+
+		})
+		var authRealm *identitatemv1alpha1.AuthRealm
+		By("creating a AuthRealm CR type ldap", func() {
+			authRealm = &identitatemv1alpha1.AuthRealm{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      AuthRealmName,
+					Namespace: AuthRealmNameSpace,
+				},
+				Spec: identitatemv1alpha1.AuthRealmSpec{
+					RouteSubDomain: RouteSubDomain,
+					Type:           identitatemv1alpha1.AuthProxyDex,
+					CertificatesSecretRef: corev1.LocalObjectReference{
+						Name: CertificatesSecretRef,
+					},
+					IdentityProviders: []openshiftconfigv1.IdentityProvider{
+						{
+							Name: "my-ldap",
+							IdentityProviderConfig: openshiftconfigv1.IdentityProviderConfig{
+								Type: openshiftconfigv1.IdentityProviderTypeLDAP,
+								LDAP: &openshiftconfigv1.LDAPIdentityProvider{
+									URL:    "myldap.example.com",
+									BindDN: BindDN,
+									Attributes: openshiftconfigv1.LDAPAttributeMapping{
+										ID:                []string{"DN"},
+										PreferredUsername: []string{"mail"},
+										Name:              []string{"cn"},
+										Email:             []string{"mail"},
+									},
+								},
+							},
+						},
+					},
+					LDAPExtraConfigs: map[string]identitatemv1alpha1.LDAPExtraConfig{
+						"my-ldap": {
+							BaseDN: BaseDN,
+							Filter: Filter,
+							GroupSearch: dexoperatorv1alpha1.GroupSearchSpec{
+								BaseDN: BaseDN,
+								Filter: GroupFilter,
+								UserMatchers: []dexoperatorv1alpha1.UserMatcher{
+									{
+										UserAttr:  UserAttr,
+										GroupAttr: GroupAttr,
+									},
+								},
+								NameAttr: NameAttr,
+							},
+						},
+					},
+				},
+			}
+			var err error
+			authRealm, err = clientSetMgmt.IdentityconfigV1alpha1().AuthRealms(AuthRealmNameSpace).Create(context.TODO(), authRealm, metav1.CreateOptions{})
+			Expect(err).To(BeNil())
+		})
+		By("Run reconcile", func() {
+			req := ctrl.Request{}
+			req.Name = AuthRealmName
+			req.Namespace = AuthRealmNameSpace
+			_, err := r.Reconcile(context.TODO(), req)
+			Expect(err).Should(BeNil())
+		})
+		By("Checking AuthRealm", func() {
+			authRealm, err := clientSetMgmt.IdentityconfigV1alpha1().AuthRealms(AuthRealmNameSpace).Get(context.TODO(), AuthRealmName, metav1.GetOptions{})
+			Expect(err).Should(BeNil())
+			status := meta.FindStatusCondition(authRealm.Status.Conditions, identitatemv1alpha1.AuthRealmApplied)
+			Expect(status).NotTo(BeNil())
+			Expect(meta.IsStatusConditionTrue(authRealm.Status.Conditions, identitatemv1alpha1.AuthRealmApplied)).To(BeTrue())
+		})
+		By("Checking Backplane Strategy", func() {
+			_, err := clientSetStrategy.IdentityconfigV1alpha1().Strategies(AuthRealmNameSpace).Get(context.TODO(), AuthRealmName+"-backplane", metav1.GetOptions{})
+			Expect(err).Should(BeNil())
+		})
+		// By("Checking GRC Strategy", func() {
+		// 	_, err := clientSetStrategy.IdentityconfigV1alpha1().Strategies(AuthRealmNameSpace).Get(context.TODO(), AuthRealmName+"-grc", metav1.GetOptions{})
+		// 	Expect(err).Should(BeNil())
+		// })
+		By("Checking Dex Operator Namespace", func() {
+			ns := &corev1.Namespace{}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.DexOperatorNamespace()}, ns)
+			Expect(err).Should(BeNil())
+		})
+		By("Checking Dex Deployment", func() {
+			ns := &appsv1.Deployment{}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: "dex-operator", Namespace: helpers.DexOperatorNamespace()}, ns)
+			Expect(err).Should(BeNil())
+		})
+		By("Checking DexServer", func() {
+			dexServer := &identitatemdexserverv1lapha1.DexServer{}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.DexServerName(), Namespace: helpers.DexServerNamespace(authRealm)}, dexServer)
+			Expect(err).Should(BeNil())
+			Expect(len(dexServer.Spec.Connectors)).To(Equal(1))
+			Expect(dexServer.Spec.Connectors[0].LDAP.BindDN).To(Equal(BindDN))
+			Expect(dexServer.Spec.Connectors[0].LDAP.UserSearch.BaseDN).To(Equal(BaseDN))
+			Expect(dexServer.Spec.Connectors[0].LDAP.UserSearch.Filter).To(Equal(Filter))
+			Expect(dexServer.Spec.Connectors[0].LDAP.GroupSearch.BaseDN).To(Equal(BaseDN))
+			Expect(dexServer.Spec.Connectors[0].LDAP.GroupSearch.Filter).To(Equal(GroupFilter))
+			Expect(dexServer.Spec.Connectors[0].LDAP.GroupSearch.UserMatchers[0].GroupAttr).To(Equal(GroupAttr))
+			Expect(dexServer.Spec.Connectors[0].LDAP.GroupSearch.UserMatchers[0].UserAttr).To(Equal(UserAttr))
+			Expect(dexServer.Spec.Connectors[0].LDAP.GroupSearch.NameAttr).To(Equal(NameAttr))
+			// Expect(dexServer.Spec.Connectors[0].Config.ClientSecretRef.Namespace).To(Equal(dexServerName))
+			Expect(dexServer.Spec.Connectors[0].Type).To(Equal(identitatemdexserverv1lapha1.ConnectorTypeLDAP))
+			Expect(dexServer.Spec.IngressCertificateRef.Name).To(Equal(authRealm.Spec.CertificatesSecretRef.Name))
+			Expect(len(dexServer.Status.RelatedObjects)).To(Equal(1))
+			Expect(dexServer.Status.RelatedObjects[0].Kind).To(Equal("AuthRealm"))
+			//TODO CA missing in Web
+		})
+	})
+
+})
+
+var _ = Describe("Process AuthRealm OpenID: ", func() {
+	AuthRealmName := "my-authrealm-openid-test"
+	AuthRealmNameSpace := "my-authrealm-openid-test"
+	RouteSubDomain := "myroute-openid"
+	MyOpenIDClientID := "my-openid-client-id"
+	CertificatesSecretRef := "my-certs"
+	It("Check CRDs availability", func() {
+		By("Checking authrealms CRD", func() {
+			readerStrategy := idpconfig.GetScenarioResourcesReader()
+			_, err := getCRD(readerStrategy, "crd/bases/identityconfig.identitatem.io_authrealms.yaml")
+			Expect(err).Should(BeNil())
+		})
+	})
+
+	It("process a AuthRealm CR with OpenID identiity provider", func() {
+		By("creation test namespace", func() {
+			ns := &corev1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: AuthRealmNameSpace,
+				},
+			}
+			err := k8sClient.Create(context.TODO(), ns)
+			Expect(err).To(BeNil())
+		})
+		By("creating the certificate secret", func() {
+			secret := &corev1.Secret{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      CertificatesSecretRef,
+					Namespace: AuthRealmNameSpace,
+				},
+				Data: map[string][]byte{
+					"tls.crt": []byte("tls.mycrt"),
+					"tls.key": []byte("tls.mykey"),
+					"ca.crt":  []byte("ca.crt"),
+				},
+			}
+			err := k8sClient.Create(context.TODO(), secret)
+			Expect(err).To(BeNil())
+
+		})
+		var authRealm *identitatemv1alpha1.AuthRealm
+		By("creating a AuthRealm CR type dex", func() {
+			authRealm = &identitatemv1alpha1.AuthRealm{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      AuthRealmName,
+					Namespace: AuthRealmNameSpace,
+				},
+				Spec: identitatemv1alpha1.AuthRealmSpec{
+					RouteSubDomain: RouteSubDomain,
+					Type:           identitatemv1alpha1.AuthProxyDex,
+					CertificatesSecretRef: corev1.LocalObjectReference{
+						Name: CertificatesSecretRef,
+					},
+					IdentityProviders: []openshiftconfigv1.IdentityProvider{
+						{
+							Name: "my-openid",
+							IdentityProviderConfig: openshiftconfigv1.IdentityProviderConfig{
+								Type: openshiftconfigv1.IdentityProviderTypeOpenID,
+								OpenID: &openshiftconfigv1.OpenIDIdentityProvider{
+									ClientID: MyOpenIDClientID,
+									ClientSecret: openshiftconfigv1.SecretNameReference{
+										Name: AuthRealmName + "-" + string(openshiftconfigv1.IdentityProviderTypeOpenID),
+									},
+								},
+							},
+						},
+					},
+				},
+			}
+			var err error
+			authRealm, err = clientSetMgmt.IdentityconfigV1alpha1().AuthRealms(AuthRealmNameSpace).Create(context.TODO(), authRealm, metav1.CreateOptions{})
+			Expect(err).To(BeNil())
+		})
+		By("Run reconcile", func() {
+			req := ctrl.Request{}
+			req.Name = AuthRealmName
+			req.Namespace = AuthRealmNameSpace
+			_, err := r.Reconcile(context.TODO(), req)
+			Expect(err).Should(BeNil())
+		})
+		By("Checking AuthRealm", func() {
+			authRealm, err := clientSetMgmt.IdentityconfigV1alpha1().AuthRealms(AuthRealmNameSpace).Get(context.TODO(), AuthRealmName, metav1.GetOptions{})
+			Expect(err).Should(BeNil())
+			status := meta.FindStatusCondition(authRealm.Status.Conditions, identitatemv1alpha1.AuthRealmApplied)
+			Expect(status).NotTo(BeNil())
+			Expect(meta.IsStatusConditionTrue(authRealm.Status.Conditions, identitatemv1alpha1.AuthRealmApplied)).To(BeTrue())
+		})
+		By("Checking Backplane Strategy", func() {
+			_, err := clientSetStrategy.IdentityconfigV1alpha1().Strategies(AuthRealmNameSpace).Get(context.TODO(), AuthRealmName+"-backplane", metav1.GetOptions{})
+			Expect(err).Should(BeNil())
+		})
+		By("Checking Dex Operator Namespace", func() {
+			ns := &corev1.Namespace{}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.DexOperatorNamespace()}, ns)
+			Expect(err).Should(BeNil())
+		})
+		By("Checking Dex Deployment", func() {
+			ns := &appsv1.Deployment{}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: "dex-operator", Namespace: helpers.DexOperatorNamespace()}, ns)
+			Expect(err).Should(BeNil())
+		})
+		By("Checking DexServer", func() {
+			dexServer := &identitatemdexserverv1lapha1.DexServer{}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.DexServerName(), Namespace: helpers.DexServerNamespace(authRealm)}, dexServer)
+			Expect(err).Should(BeNil())
+			Expect(len(dexServer.Spec.Connectors)).To(Equal(1))
+			Expect(dexServer.Spec.Connectors[0].OIDC.ClientID).To(Equal(MyOpenIDClientID))
+			Expect(dexServer.Spec.Connectors[0].OIDC.ClientSecretRef.Name).To(Equal(AuthRealmName + "-" + string(openshiftconfigv1.IdentityProviderTypeOpenID)))
+			Expect(dexServer.Spec.Connectors[0].Type).To(Equal(identitatemdexserverv1lapha1.ConnectorTypeOIDC))
+
+		})
+	})
+
+})
+
 func getCRD(reader *clusteradmasset.ScenarioResourcesReader, file string) (*apiextensionsv1.CustomResourceDefinition, error) {
 	b, err := reader.Asset(file)
 	if err != nil {
